Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to AWS IQ Permissions.

Actions, resources, and condition keys for AWS IQ Permissions - Service Authorization Reference

# Actions, resources, and condition keys for AWS IQ Permissions

AWS IQ Permissions (service prefix: `iq-permission` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

###### Topics

- Actions defined by AWS IQ Permissions
- Resource types defined by AWS IQ Permissions
- Condition keys for AWS IQ Permissions

## Actions defined by AWS IQ Permissions

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column of the Actions table indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") to which the policy applies in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. If the action has one or more required resources, the caller must have permission to use the action with those resources. Required resources are indicated in the table with an asterisk (*). If you limit resource access with the `Resource` element in an IAM policy, you must include an ARN or pattern for each required resource type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one of the optional resource types.

The Condition keys column of the Actions table includes keys that you can specify in a policy statement's `Condition` element. For more information on the condition keys that are associated with resources for the service, see the Condition keys column of the Resource types table.

For details about the columns in the following table, see Actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
ApproveAccessGrant | Grants permission to approve a permission request | Write | permission* |  |
ApprovePermissionRequest | Grants permission to approve a permission request | Write | permission* |  |
CreatePermissionRequest | Grants permission to create a permission request | Write | permission* |  |
GetPermissionRequest | Grants permission to get a permission request | Read | permission* |  |
ListPermissionRequests | Grants permission to list permission requests | Read | permission* |  |
RejectPermissionRequest | Grants permission to reject a permission request | Write | permission* |  |
RevokePermissionRequest | Grants permission to revoke a permission request which was previously approved | Write | permission* |  |
WithdrawPermissionRequest | Grants permission to withdraw a permission request that has not been approved or declined | Write | permission* |  |

## Resource types defined by AWS IQ Permissions

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the Resource types table. For details about the columns in the following table, see Resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
permission | `arn:$ { Partition}:iq-permission:$ { Region}::permission/$ { PermissionRequestId}` |

## Condition keys for AWS IQ Permissions

IQ Permission has no service-specific context keys that can be used in the `Condition` element of policy statements. For the list of the global context keys that are available to all services, see Available keys for conditions .

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.